# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: examples/order.proto
# Protobuf Python Version: 6.33.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    5,
    '',
    'examples/order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x65xamples/order.proto\x12\x08\x65xamples\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9a\x01\n\x0b\x43reateOrder\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x12.examples.LineItemR\x05items\x12#\n\rcustomer_root\x18\x03 \x01(\x0cR\x0c\x63ustomerRoot\x12\x1b\n\tcart_root\x18\x04 \x01(\x0cR\x08\x63\x61rtRoot\"U\n\x14\x41pplyLoyaltyDiscount\x12\x16\n\x06points\x18\x01 \x01(\x05R\x06points\x12%\n\x0e\x64iscount_cents\x18\x02 \x01(\x05R\rdiscountCents\"Y\n\rSubmitPayment\x12%\n\x0epayment_method\x18\x01 \x01(\tR\rpaymentMethod\x12!\n\x0c\x61mount_cents\x18\x02 \x01(\x05R\x0b\x61mountCents\"=\n\x0e\x43onfirmPayment\x12+\n\x11payment_reference\x18\x01 \x01(\tR\x10paymentReference\"%\n\x0b\x43\x61ncelOrder\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\"\xfd\x01\n\x0cOrderCreated\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x12.examples.LineItemR\x05items\x12%\n\x0esubtotal_cents\x18\x03 \x01(\x05R\rsubtotalCents\x12\x39\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12#\n\rcustomer_root\x18\x05 \x01(\x0cR\x0c\x63ustomerRoot\x12\x1b\n\tcart_root\x18\x06 \x01(\x0cR\x08\x63\x61rtRoot\"\x9b\x01\n\x16LoyaltyDiscountApplied\x12\x1f\n\x0bpoints_used\x18\x01 \x01(\x05R\npointsUsed\x12%\n\x0e\x64iscount_cents\x18\x02 \x01(\x05R\rdiscountCents\x12\x39\n\napplied_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tappliedAt\"\x9b\x01\n\x10PaymentSubmitted\x12%\n\x0epayment_method\x18\x01 \x01(\tR\rpaymentMethod\x12!\n\x0c\x61mount_cents\x18\x02 \x01(\x05R\x0b\x61mountCents\x12=\n\x0csubmitted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bsubmittedAt\"\x9d\x03\n\x0eOrderCompleted\x12*\n\x11\x66inal_total_cents\x18\x01 \x01(\x05R\x0f\x66inalTotalCents\x12%\n\x0epayment_method\x18\x02 \x01(\tR\rpaymentMethod\x12+\n\x11payment_reference\x18\x03 \x01(\tR\x10paymentReference\x12\x32\n\x15loyalty_points_earned\x18\x04 \x01(\x05R\x13loyaltyPointsEarned\x12=\n\x0c\x63ompleted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63ompletedAt\x12#\n\rcustomer_root\x18\x06 \x01(\x0cR\x0c\x63ustomerRoot\x12\x1b\n\tcart_root\x18\x07 \x01(\x0cR\x08\x63\x61rtRoot\x12(\n\x05items\x18\x08 \x03(\x0b\x32\x12.examples.LineItemR\x05items\x12,\n\x12\x66raud_check_result\x18\t \x01(\tR\x10\x66raudCheckResult\"\x83\x02\n\x0eOrderCancelled\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\x12=\n\x0c\x63\x61ncelled_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63\x61ncelledAt\x12.\n\x13loyalty_points_used\x18\x03 \x01(\x05R\x11loyaltyPointsUsed\x12#\n\rcustomer_root\x18\x04 \x01(\x0cR\x0c\x63ustomerRoot\x12(\n\x05items\x18\x05 \x03(\x0b\x32\x12.examples.LineItemR\x05items\x12\x1b\n\tcart_root\x18\x06 \x01(\x0cR\x08\x63\x61rtRoot\"\xa6\x01\n\x08LineItem\x12\x1d\n\nproduct_id\x18\x01 \x01(\tR\tproductId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1a\n\x08quantity\x18\x03 \x01(\x05R\x08quantity\x12(\n\x10unit_price_cents\x18\x04 \x01(\x05R\x0eunitPriceCents\x12!\n\x0cproduct_root\x18\x05 \x01(\x0cR\x0bproductRoot\"\x83\x03\n\nOrderState\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x12.examples.LineItemR\x05items\x12%\n\x0esubtotal_cents\x18\x03 \x01(\x05R\rsubtotalCents\x12%\n\x0e\x64iscount_cents\x18\x04 \x01(\x05R\rdiscountCents\x12.\n\x13loyalty_points_used\x18\x05 \x01(\x05R\x11loyaltyPointsUsed\x12%\n\x0epayment_method\x18\x06 \x01(\tR\rpaymentMethod\x12+\n\x11payment_reference\x18\x07 \x01(\tR\x10paymentReference\x12\x16\n\x06status\x18\x08 \x01(\tR\x06status\x12#\n\rcustomer_root\x18\t \x01(\x0cR\x0c\x63ustomerRoot\x12\x1b\n\tcart_root\x18\n \x01(\x0cR\x08\x63\x61rtRootB\x8e\x01\n\x0c\x63om.examplesB\nOrderProtoP\x01Z2github.com/angzarr/angzarr/proto/examples;examples\xa2\x02\x03\x45XX\xaa\x02\x08\x45xamples\xca\x02\x08\x45xamples\xe2\x02\x14\x45xamples\\GPBMetadata\xea\x02\x08\x45xamplesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'examples.order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.examplesB\nOrderProtoP\001Z2github.com/angzarr/angzarr/proto/examples;examples\242\002\003EXX\252\002\010Examples\312\002\010Examples\342\002\024Examples\\GPBMetadata\352\002\010Examples'
  _globals['_CREATEORDER']._serialized_start=68
  _globals['_CREATEORDER']._serialized_end=222
  _globals['_APPLYLOYALTYDISCOUNT']._serialized_start=224
  _globals['_APPLYLOYALTYDISCOUNT']._serialized_end=309
  _globals['_SUBMITPAYMENT']._serialized_start=311
  _globals['_SUBMITPAYMENT']._serialized_end=400
  _globals['_CONFIRMPAYMENT']._serialized_start=402
  _globals['_CONFIRMPAYMENT']._serialized_end=463
  _globals['_CANCELORDER']._serialized_start=465
  _globals['_CANCELORDER']._serialized_end=502
  _globals['_ORDERCREATED']._serialized_start=505
  _globals['_ORDERCREATED']._serialized_end=758
  _globals['_LOYALTYDISCOUNTAPPLIED']._serialized_start=761
  _globals['_LOYALTYDISCOUNTAPPLIED']._serialized_end=916
  _globals['_PAYMENTSUBMITTED']._serialized_start=919
  _globals['_PAYMENTSUBMITTED']._serialized_end=1074
  _globals['_ORDERCOMPLETED']._serialized_start=1077
  _globals['_ORDERCOMPLETED']._serialized_end=1490
  _globals['_ORDERCANCELLED']._serialized_start=1493
  _globals['_ORDERCANCELLED']._serialized_end=1752
  _globals['_LINEITEM']._serialized_start=1755
  _globals['_LINEITEM']._serialized_end=1921
  _globals['_ORDERSTATE']._serialized_start=1924
  _globals['_ORDERSTATE']._serialized_end=2311
# @@protoc_insertion_point(module_scope)
